#' sparsevar: A package to estimate multivariate time series models
#' (such as VAR and VECM), under the sparsity hypothesis.
#'
#' It performs the estimation of the matrices of the models using penalized
#' least squares methods such as LASSO, SCAD and MCP.
#'
#' @section sparsevar functions:
#' \code{fit_var}, \code{fit_vecm}, \code{simulate_var},
#' \code{create_sparse_matrix},
#' \code{plotMatrix}, \code{plotVAR}, \code{plotVECM}
#' \code{l2norm}, \code{l1norm}, \code{lInftyNorm}, \code{maxNorm},
#' \code{frobNorm},
#' \code{spectralRadius}, \code{spectralNorm}, \code{impulseResponse}
#'
#' @name sparsevar
#'
"_PACKAGE"
